==> kadu-0.3.9.tar.bz2: kadu/modules/default_sms/translations/default_sms_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>SMS EraGSM Gateway</translation>
    </message>
    <message>
        <source>User ID</source>
        <translation>ID dell&apos;utente</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Tipo di Gateway</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Errore:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Nessun errore</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Guasto del sistema</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Utente non autorizzato</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Accesso proibito</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Errore di sintassi</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>limite quantitativo SMS raggiunto</translation>
    </message>
    <message>
        <source>Wrong receiver adress</source>
        <translation>Indirizzo del ricevente SMS errato</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Messaggio troppo lungo</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
</context>
<context>
    <name>SmsIdeaGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del fornitore sembra sconosciuta.
Probabilmente è temporaneamente disabilitata, o sono state cambiate le regole d&apos;accesso.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>Avete superato il vostro limite quotidiano di SMS inviati</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Il testo d&apos;immagine errato</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Il ricevente deve consentire (attivare) il servizio di STANDARD SMS</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del operatore GSM sembra sconosciuta.
Probabilmente è temporaneamente disattivata, o sono state cambiate le reole accesso.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway del operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
</context>
</TS>

==> kadu-0.4.1.tar.bz2: kadu/modules/default_sms/translations/default_sms_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>SMS EraGSM Gateway</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Tipo di Gateway</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>User ID (39xxxxxxxxx)</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Errore:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Nessun errore</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Guasto del sistema</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Utente non autorizzato</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Accesso proibito</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Errore di sintassi</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>limite quantitativo SMS raggiunto</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Messaggio troppo lungo</translation>
    </message>
    <message>
        <source>Wrong receiver address</source>
        <translation>Indirizzo destinatario errato</translation>
    </message>
    <message>
        <source>Unknown error (%1)</source>
        <translation>Errore sconosciuto (%1)</translation>
    </message>
</context>
<context>
    <name>SmsIdeaGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del fornitore sembra sconosciuta.
Probabilmente è temporaneamente disabilitata, o sono state cambiate le regole d&apos;accesso.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>Avete superato il vostro limite quotidiano di SMS inviati</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Il testo d&apos;immagine errato</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Il ricevente deve consentire (attivare) il servizio di STANDARD SMS</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del operatore GSM sembra sconosciuta.
Probabilmente è temporaneamente disattivata, o sono state cambiate le reole accesso.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway del operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <source>Limits have been exceeded, try again later.</source>
        <translation>I limiti sono stati raggiunti, riprova pi? tardi.</translation>
    </message>
</context>
</TS>
